# Users

::: harborapi.client.HarborAsyncClient
    options:
        members:
        - get_user
        - get_user_by_username
        - create_user
        - update_user
        - delete_user
        - get_users
        - search_users_by_username
        - set_user_admin
        - set_user_password
        - set_user_cli_secret
        - get_current_user
        - get_current_user_permissions
